__author__ = 'kuyaki'
__copyright__ = '2020 KuYaki'
__credits__ = ['kuyaki']
__maintainer__ = 'kuyaki'
__date__ = '2020/10/02'
__version__ = '0.0.3'

from gitmodules.gitmodules import extend_paths


extend_paths()
